@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit.c 5988 2007-10-28 14:44:53Z sfre $
+ * $Id: gedit.c 6039 2007-12-28 19:52:37Z sfre $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -444,6 +444,7 @@ main (int argc, char *argv[])
 {
 	GnomeProgram *program;
 	GOptionContext *context;
+	GeditPluginsEngine *engine;
 	GeditWindow *window;
 	GeditApp *app;
 	gboolean restored = FALSE;
@@ -529,8 +530,8 @@ main (int argc, char *argv[])
 	gnome_authentication_manager_init ();
 	
 	/* Init plugins engine */
-	gedit_debug_message (DEBUG_APP, "Init plugins");	
-	gedit_plugins_engine_init ();
+	gedit_debug_message (DEBUG_APP, "Init plugins");
+	engine = gedit_plugins_engine_get_default ();
 
 	gtk_about_dialog_set_url_hook (gedit_utils_activate_url, NULL, NULL);
 	
@@ -586,12 +587,13 @@ main (int argc, char *argv[])
 
 	bacon_message_connection_free (connection);
 
-	gedit_plugins_engine_shutdown ();
+	/* We kept the original engine reference here. So let's unref it to
+	 * finalize it properly. 
+	 */
+	g_object_unref (engine);
 	gedit_prefs_manager_app_shutdown ();
 	gedit_metadata_manager_shutdown ();
 
-	gnome_accelerators_sync ();
-
 	g_object_unref (program);
 
 	return 0;
