@@ -20,7 +20,7 @@ __all__ = ('Manager', )
 
 import gedit
 import gtk
-import gtksourceview as gsv
+import gtksourceview2 as gsv
 from gtk import glade
 import os.path
 from library import *
@@ -45,7 +45,7 @@ class Manager(object):
             ('word'     , _('Current word'))
         ),
         'output': (
-            ('output-panel'     , _('Insert in output panel')),
+            ('output-panel'     , _('Display in bottom pane')),
             ('new-document'     , _('Create new document')),
             ('append-document'  , _('Append to current document')),
             ('replace-document' , _('Replace current document')),
@@ -133,8 +133,8 @@ class Manager(object):
     def custom_handler(self, xml, function_name, widget_name,
                        str1, str2, int1 , int2):
         if function_name == 'create_commands':
-            buf = gsv.SourceBuffer()
-            view = gsv.SourceView(buf)
+            buf = gsv.Buffer()
+            view = gsv.View(buf)
             view.set_wrap_mode(gtk.WRAP_WORD)
             view.show()
             return view
@@ -175,7 +175,7 @@ class Manager(object):
             return combo.get_model().get_value(combo.get_active_iter(), self.NAME_COLUMN)
 
         self.current_node.input = combo_value(self, 'input')
-        self.current_node.ouput = combo_value(self, 'output')
+        self.current_node.output = combo_value(self, 'output')
         self.current_node.applicability = combo_value(self, 'applicability')
         self.current_node.comment = self['description'].get_text()
 
@@ -209,12 +209,14 @@ class Manager(object):
         buf.set_text(script)
         self.script_hash = self.compute_hash(script)
         mimetype = gnomevfs.get_mime_type_for_data(script)
-        language = gsv.SourceLanguagesManager().get_language_from_mime_type(mimetype)
+        lmanager = gedit.get_language_manager()
+        language = gedit.language_manager_get_language_from_mime_type(lmanager, mimetype)
+
         if language is not None:
             buf.set_language(language)
-            buf.set_highlight(True)
+            buf.set_highlight_syntax(True)
         else:
-            buf.set_highlight(False)
+            buf.set_highlight_syntax(False)
 
         self.set_active_by_name('input',
                                 default(node.input,
@@ -251,7 +253,7 @@ class Manager(object):
         if node.is_global():
             if node.parent.revert_tool(node):
                 if self.current_node.shortcut and \
-                   self.accelerator.has_key(self.current_node.shortcut):
+                   self.current_node.shortcut in self.accelerator:
                     del self.accelerators[self.current_node.shortcut]                
                 self['revert-tool-button'].set_sensitive(False)
                 self.fill_fields()
@@ -304,7 +306,7 @@ class Manager(object):
             del self.accelerators[self.current_node.shortcut]
         name = gtk.accelerator_name(keyval, mod)
         if name != '':
-            if self.accelerators.has_key(name):
+            if name in self.accelerators:
                 dialog = gtk.MessageDialog(self.dialog,
                                            gtk.DIALOG_MODAL,
                                            gtk.MESSAGE_ERROR,
@@ -363,7 +365,6 @@ class Manager(object):
         if self.current_node is not None:
             entry.set_text(default(self.current_node.shortcut, ''))
 
-
     def on_tool_manager_dialog_response(self, dialog, response):
         if response == gtk.RESPONSE_HELP:
             gedit.help_display(self.dialog, 'gedit.xml', 'gedit-external-tools-plugin')
